@@ -4,7 +4,7 @@
 //                                                                          //
 //                            G N A T _ l i b c                             //
 //                                                                          //
-//                     Copyright (C) 1998-2009, AdaCore                     //
+//                     Copyright (C) 1998-2011, AdaCore                     //
 //                                                                          //
 // GNAT is free software;  you can  redistribute it  and/or modify it under //
 // terms of the  GNU General Public License as published  by the Free Soft- //
@@ -155,7 +155,7 @@ namespace mgnat.adalib
 
       //  Given a java.lang.Class object, the following returns an array of bytes
       //  containing the fully qualified name of that class. Because of the way
-      //  JGNAT maps Ada tagged (and untagged) records and exceptions to Java
+      //  DOTGNAT maps Ada tagged (and untagged) records and exceptions to CIL
       //  classes this routine is use to implement Ada.Tags.Expanded_Name and
       //  Ada.Exceptions.Exception_Name.
 
@@ -175,11 +175,23 @@ namespace mgnat.adalib
       {
          //  First get the actual external tag
          byte[] s = external_tag (t);
-         byte[] r = new byte[s.Length];
+         int s_length = s.Length;
+
+         //  Search for the comma separator of AssemblyQualifiedName
+
+         int j = 0;
+         while ((j < s_length) && (s[j] != ',')) {
+            j++;
+         }
+         s_length = j;
+
+         //  Do not copy text after the comma
+
+         byte[] r = new byte[s_length];
 
          int r_pos = 0;
 
-         for (int k = 0; k < s.Length; k++)
+         for (int k = 0; k < s_length; k++)
          {
             if ((s[k] == (byte)'_') && (s[k + 1] == (byte)'_'))
             {
@@ -299,7 +311,7 @@ namespace mgnat.adalib
          //  Because this functionality is not directly available in the Java API
          //  the C routines that are used in the GNAT sources and that may cause
          //  ferror to return a non zero value (fgetc, getc_immediate,
-         //  getc_imediate_nowait, and fread) are implemented as follows:
+         //  getc_immediate_nowait, and fread) are implemented as follows:
          //
          //        getc (...) {
          //           try {
@@ -1672,6 +1684,7 @@ namespace mgnat.adalib
       //////////////////////////////
 
       public static int __gl_main_priority = -1;
+      public static int __gl_main_cpu = -1;
       public static int __gl_time_slice_val = -1;
       public static byte __gl_wc_encoding = (byte)'n';
       public static byte __gl_locking_policy = (byte)' ';
@@ -1725,7 +1738,7 @@ namespace mgnat.adalib
 
       public static byte[] external_tag (Object t)
       {
-         String s = ((System.Type)t).FullName;
+         String s = ((System.Type)t).AssemblyQualifiedName;
 
          return getBytes (s);
       }
@@ -1979,5 +1992,11 @@ namespace mgnat.adalib
      {
         return !(Double.IsNaN(fl) || Double.IsNegativeInfinity(fl) || Double.IsPositiveInfinity(fl));
      }
+
+     public static int __gnat_number_of_cpus ()
+     {
+        // ??? dummy implementation
+        return 1;
+     }
    }
 } //namespace
